==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_hsb.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_hsb extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ALL", "ALL" },
            { "AUD", "AUD" },
            { "BGN", "BGN" },
            { "JPY", "\u00a5" },
            { "KPW", "KPW" },
            { "PLN", "z\u0142" },
            { "THB", "\u0e3f" },
            { "USD", "$" },
            { "adp", "andorraska peseta" },
            { "aed", "ZAE dirham" },
            { "afn", "afghaniski afghani" },
            { "all", "albanski lek" },
            { "amd", "armenski dram" },
            { "ang", "ni\u017eozemsko-antilski gulden" },
            { "aoa", "angolska kwanza" },
            { "aok", "angolska kwanza (1977\u20131990)" },
            { "aon", "angolska nowa kwanza (1990\u20132000)" },
            { "aor", "angolska kwanza reajustado (1995\u20131999)" },
            { "ara", "argentinski austral" },
            { "arp", "argentinski peso (1983\u20131985)" },
            { "ars", "argentinski peso" },
            { "ats", "awstriski \u0161iling" },
            { "aud", "awstralski dolar" },
            { "awg", "aruba-florin" },
            { "azm", "azerbajd\u017aanski manat (1993\u20132006)" },
            { "azn", "azerbajd\u017aanski manat" },
            { "bad", "bosniski dinar" },
            { "bam", "bosniska konwertibelna hriwna" },
            { "bbd", "barbadoski dolar" },
            { "bdt", "banglade\u0161ska taka" },
            { "bec", "belgiski frank (konwertibelny)" },
            { "bef", "belgiski frank" },
            { "bel", "belgiski finan\u010dny frank" },
            { "bgl", "bo\u0142harski lew (1962\u20131999)" },
            { "bgn", "bo\u0142harski lew" },
            { "bhd", "bahrainski dinar" },
            { "bif", "burundiski frank" },
            { "bmd", "bermudaski dolar" },
            { "bnd", "bruneiski dolar" },
            { "bob", "boliwiski boliviano" },
            { "bop", "boliwiski peso" },
            { "bov", "boliwiski mvdol" },
            { "brb", "brazilski nowy cruzeiro (1967\u20131986)" },
            { "brc", "brazilski cruzado (1986\u20131989)" },
            { "bre", "brazilski cruzeiro (1990\u20131993)" },
            { "brl", "brazilski real" },
            { "brn", "brazilski nowy cruzado (1989\u20131990)" },
            { "brr", "brazilski cruzeiro (1993\u20131994)" },
            { "bsd", "bahamaski dolar" },
            { "btn", "bhutanski ngultrum" },
            { "buk", "burmaski kyat" },
            { "bwp", "botswanska pula" },
            { "byb", "b\u011b\u0142oruski rubl (1994\u20131999)" },
            { "byn", "b\u011b\u0142oruski rubl" },
            { "byr", "b\u011b\u0142oruski rubl (2000\u20132016)" },
            { "bzd", "belizeski dolar" },
            { "cad", "kanadiski dolar" },
            { "cdf", "kongoski frank" },
            { "chf", "\u0161wicarski frank" },
            { "clp", "chilski peso" },
            { "cnh", "chinski yuan (offshore)" },
            { "cny", "chinski yuan" },
            { "cop", "kolumbiski peso" },
            { "crc", "kosta-rikaski col\u00f3n" },
            { "cuc", "kubaski konwertibelny peso" },
            { "cup", "kubaski peso" },
            { "cve", "kapverdski escudo" },
            { "czk", "\u010d\u011bska kr\u00f3na" },
            { "djf", "d\u017aibutiski frank" },
            { "dkk", "danska kr\u00f3na" },
            { "dop", "dominikanski peso" },
            { "dzd", "algeriski dinar" },
            { "egp", "egyptowski punt" },
            { "ern", "eritrejska nakfa" },
            { "etb", "etiopiski birr" },
            { "eur", "euro" },
            { "fjd", "fid\u017aiski dolar" },
            { "fkp", "falklandski punt" },
            { "gbp", "britiski punt" },
            { "gel", "georgiski lari" },
            { "ghs", "ghanaski cedi" },
            { "gip", "gibraltarski punt" },
            { "gmd", "gambiski dalasi" },
            { "gnf", "ginejski frank" },
            { "gtq", "guatemalski quetzal" },
            { "gwp", "ginejsko-bissauski peso" },
            { "gyd", "guyanski dolar" },
            { "hkd", "hongkongski dolar" },
            { "hnl", "honduraska lempira" },
            { "hrk", "chorwatska kuna" },
            { "htg", "haitiska gourda" },
            { "huf", "mad\u017aarski forint" },
            { "idr", "indoneska rupija" },
            { "ils", "israelski nowy \u0161ekel" },
            { "inr", "indiska rupija" },
            { "iqd", "irakski dinar" },
            { "irr", "iranski rial" },
            { "isk", "islandska kr\u00f3na" },
            { "jmd", "jamaiski dolar" },
            { "jod", "jordaniski dinar" },
            { "jpy", "japanski yen" },
            { "kes", "keniaski \u0161iling" },
            { "kgs", "kirgiski som" },
            { "khr", "kambod\u017aaski riel" },
            { "kmf", "komorski frank" },
            { "kpw", "sewjernokorejski won" },
            { "krw", "ju\u017enokorejski won" },
            { "kwd", "kuwaitski dinar" },
            { "kyd", "kajmanski dolar" },
            { "kzt", "kazachski tenge" },
            { "lak", "laoski kip" },
            { "lbp", "libanonski punt" },
            { "lkr", "sri-lankaska rupija" },
            { "lrd", "liberiski dolar" },
            { "lsl", "lesothiski loti" },
            { "ltl", "litawski litas" },
            { "lvl", "letiski lat" },
            { "lyd", "libyski dinar" },
            { "mad", "marokkoski dirham" },
            { "mdl", "moldawski leu" },
            { "mga", "madagaskarski ariary" },
            { "mkd", "makedonski denar" },
            { "mmk", "myanmarski kyat" },
            { "mnt", "mongolski tugrik" },
            { "mop", "macaoska pataka" },
            { "mro", "mawretanska ouguiya (1973\u20132017)" },
            { "mru", "mawretanska ouguiya" },
            { "mur", "mauritiuska rupija" },
            { "mvr", "malediwiska rupija" },
            { "mwk", "malawiski kwacha" },
            { "mxn", "mexiski peso" },
            { "myr", "malajziski ringgit" },
            { "mze", "mosambikski escudo" },
            { "mzm", "mosambikski metical (1980\u20132006)" },
            { "mzn", "mosambikski metical" },
            { "nad", "namibiski dolar" },
            { "ngn", "nigeriski naira" },
            { "nio", "nikaraguaski cordoba" },
            { "nok", "norwegska kr\u00f3na" },
            { "npr", "nepalska rupija" },
            { "nzd", "nowoseelandski dolar" },
            { "omr", "omanski rial" },
            { "pab", "panamaski balboa" },
            { "pen", "peruski sol" },
            { "pgk", "papua-nowoginejski kina" },
            { "php", "filipinski peso" },
            { "pkr", "pakistanska rupija" },
            { "pln", "p\u00f3lski z\u0142oty" },
            { "pyg", "paraguayski guarani" },
            { "qar", "katarski rial" },
            { "ron", "rumunski leu" },
            { "rsd", "serbiski dinar" },
            { "rub", "ruski rubl" },
            { "rwf", "ruandiski frank" },
            { "sar", "saudi-arabski rial" },
            { "sbd", "salomonski dolar" },
            { "scr", "seychellska rupija" },
            { "sdg", "sudanski punt" },
            { "sek", "\u0161wedska kr\u00f3na" },
            { "sgd", "singapurski dolar" },
            { "shp", "St. Helenski punt" },
            { "sll", "sierra-leoneski leone" },
            { "sos", "somaliski \u0161iling" },
            { "srd", "surinamski dolar" },
            { "ssp", "ju\u017enosudanski punt" },
            { "std", "s\u00e3o tomeski dobra (1977\u20132017)" },
            { "stn", "s\u00e3o tomeski dobra" },
            { "svc", "el salvadorski col\u00f3n" },
            { "syp", "syriski punt" },
            { "szl", "swasiski lilangeni" },
            { "thb", "thaiski baht" },
            { "tjs", "tad\u017aikski somoni" },
            { "tmt", "turkmenski manat" },
            { "tnd", "tuneziski dinar" },
            { "top", "tongaski pa\u02bbanga" },
            { "try", "turkowska lira" },
            { "ttd", "trinidad-tobagoski dolar" },
            { "twd", "nowy taiwanski dolar" },
            { "tzs", "tansaniski \u0161iling" },
            { "uah", "ukrainska hriwna" },
            { "ugx", "ugandaski \u0161iling" },
            { "usd", "ameriski dolar" },
            { "uyu", "uruguayski peso" },
            { "uzs", "uzbekski sum" },
            { "vef", "venezuelski bol\u00edvar (2008\u20132018)" },
            { "ves", "venezuelski bol\u00edvar" },
            { "vnd", "vietnamski dong" },
            { "vuv", "vanuatuski vatu" },
            { "wst", "samoaski tala" },
            { "xaf", "CFA-frank (BEAC)" },
            { "xcd", "wuchodnokaribiski dolar" },
            { "xof", "CFA-frank (BCEAO)" },
            { "xpf", "CFP-frank" },
            { "xxx", "njeznata m\u011bna" },
            { "yer", "jemenski rial" },
            { "zar", "ju\u017enoafriski rand" },
            { "zmw", "sambiski kwacha" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_hsb.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_hsb extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AUD", "AUD" },
            { "JPY", "\u00a5" },
            { "PLN", "z\u0142" },
            { "THB", "\u0e3f" },
            { "USD", "$" },
            { "adp", "andorraska peseta" },
            { "aed", "ZAE dirham" },
            { "afn", "afghaniski afghani" },
            { "all", "albanski lek" },
            { "amd", "armenski dram" },
            { "ang", "ni\u017eozemsko-antilski gulden" },
            { "aoa", "angolska kwanza" },
            { "aok", "angolska kwanza (1977\u20131990)" },
            { "aon", "angolska nowa kwanza (1990\u20132000)" },
            { "aor", "angolska kwanza reajustado (1995\u20131999)" },
            { "ara", "argentinski austral" },
            { "arp", "argentinski peso (1983\u20131985)" },
            { "ars", "argentinski peso" },
            { "ats", "awstriski \u0161iling" },
            { "aud", "awstralski dolar" },
            { "awg", "aruba-florin" },
            { "azm", "azerbajd\u017aanski manat (1993\u20132006)" },
            { "azn", "azerbajd\u017aanski manat" },
            { "bad", "bosniski dinar" },
            { "bam", "bosniska konwertibelna hriwna" },
            { "bbd", "barbadoski dolar" },
            { "bdt", "banglade\u0161ska taka" },
            { "bec", "belgiski frank (konwertibelny)" },
            { "bef", "belgiski frank" },
            { "bel", "belgiski finan\u010dny frank" },
            { "bgl", "bo\u0142harski lew (1962\u20131999)" },
            { "bgn", "bo\u0142harski lew" },
            { "bhd", "bahrainski dinar" },
            { "bif", "burundiski frank" },
            { "bmd", "bermudaski dolar" },
            { "bnd", "bruneiski dolar" },
            { "bob", "boliwiski boliviano" },
            { "bop", "boliwiski peso" },
            { "bov", "boliwiski mvdol" },
            { "brb", "brazilski nowy cruzeiro (1967\u20131986)" },
            { "brc", "brazilski cruzado (1986\u20131989)" },
            { "bre", "brazilski cruzeiro (1990\u20131993)" },
            { "brl", "brazilski real" },
            { "brn", "brazilski nowy cruzado (1989\u20131990)" },
            { "brr", "brazilski cruzeiro (1993\u20131994)" },
            { "bsd", "bahamaski dolar" },
            { "btn", "bhutanski ngultrum" },
            { "buk", "burmaski kyat" },
            { "bwp", "botswanska pula" },
            { "byb", "b\u011b\u0142oruski rubl (1994\u20131999)" },
            { "byn", "b\u011b\u0142oruski rubl" },
            { "byr", "b\u011b\u0142oruski rubl (2000\u20132016)" },
            { "bzd", "belizeski dolar" },
            { "cad", "kanadiski dolar" },
            { "cdf", "kongoski frank" },
            { "chf", "\u0161wicarski frank" },
            { "clp", "chilski peso" },
            { "cnh", "chinski yuan (offshore)" },
            { "cny", "chinski yuan" },
            { "cop", "kolumbiski peso" },
            { "crc", "kosta-rikaski col\u00f3n" },
            { "cuc", "kubaski konwertibelny peso" },
            { "cup", "kubaski peso" },
            { "cve", "kapverdski escudo" },
            { "czk", "\u010d\u011bska kr\u00f3na" },
            { "djf", "d\u017aibutiski frank" },
            { "dkk", "danska kr\u00f3na" },
            { "dop", "dominikanski peso" },
            { "dzd", "algeriski dinar" },
            { "egp", "egyptowski punt" },
            { "ern", "eritrejska nakfa" },
            { "etb", "etiopiski birr" },
            { "eur", "euro" },
            { "fjd", "fid\u017aiski dolar" },
            { "fkp", "falklandski punt" },
            { "gbp", "britiski punt" },
            { "gel", "georgiski lari" },
            { "ghs", "ghanaski cedi" },
            { "gip", "gibraltarski punt" },
            { "gmd", "gambiski dalasi" },
            { "gnf", "ginejski frank" },
            { "gtq", "guatemalski quetzal" },
            { "gwp", "ginejsko-bissauski peso" },
            { "gyd", "guyanski dolar" },
            { "hkd", "hongkongski dolar" },
            { "hnl", "honduraska lempira" },
            { "hrk", "chorwatska kuna" },
            { "htg", "haitiska gourda" },
            { "huf", "mad\u017aarski forint" },
            { "idr", "indoneska rupija" },
            { "ils", "israelski nowy \u0161ekel" },
            { "inr", "indiska rupija" },
            { "iqd", "irakski dinar" },
            { "irr", "iranski rial" },
            { "isk", "islandska kr\u00f3na" },
            { "jmd", "jamaiski dolar" },
            { "jod", "jordaniski dinar" },
            { "jpy", "japanski yen" },
            { "kes", "keniaski \u0161iling" },
            { "kgs", "kirgiski som" },
            { "khr", "kambod\u017aaski riel" },
            { "kmf", "komorski frank" },
            { "kpw", "sewjernokorejski won" },
            { "krw", "ju\u017enokorejski won" },
            { "kwd", "kuwaitski dinar" },
            { "kyd", "kajmanski dolar" },
            { "kzt", "kazachski tenge" },
            { "lak", "laoski kip" },
            { "lbp", "libanonski punt" },
            { "lkr", "sri-lankaska rupija" },
            { "lrd", "liberiski dolar" },
            { "lsl", "lesothiski loti" },
            { "ltl", "litawski litas" },
            { "lvl", "letiski lat" },
            { "lyd", "libyski dinar" },
            { "mad", "marokkoski dirham" },
            { "mdl", "moldawski leu" },
            { "mga", "madagaskarski ariary" },
            { "mkd", "makedonski denar" },
            { "mmk", "myanmarski kyat" },
            { "mnt", "mongolski tugrik" },
            { "mop", "macaoska pataka" },
            { "mro", "mawretanska ouguiya (1973\u20132017)" },
            { "mru", "mawretanska ouguiya" },
            { "mur", "mauritiuska rupija" },
            { "mvr", "malediwiska rupija" },
            { "mwk", "malawiski kwacha" },
            { "mxn", "mexiski peso" },
            { "myr", "malajziski ringgit" },
            { "mze", "mosambikski escudo" },
            { "mzm", "mosambikski metical (1980\u20132006)" },
            { "mzn", "mosambikski metical" },
            { "nad", "namibiski dolar" },
            { "ngn", "nigeriski naira" },
            { "nio", "nikaraguaski cordoba" },
            { "nok", "norwegska kr\u00f3na" },
            { "npr", "nepalska rupija" },
            { "nzd", "nowoseelandski dolar" },
            { "omr", "omanski rial" },
            { "pab", "panamaski balboa" },
            { "pen", "peruski sol" },
            { "pgk", "papua-nowoginejski kina" },
            { "php", "filipinski peso" },
            { "pkr", "pakistanska rupija" },
            { "pln", "p\u00f3lski z\u0142oty" },
            { "pyg", "paraguayski guarani" },
            { "qar", "katarski rial" },
            { "ron", "rumunski leu" },
            { "rsd", "serbiski dinar" },
            { "rub", "ruski rubl" },
            { "rwf", "ruandiski frank" },
            { "sar", "saudi-arabski rial" },
            { "sbd", "salomonski dolar" },
            { "scr", "seychellska rupija" },
            { "sdg", "sudanski punt" },
            { "sek", "\u0161wedska kr\u00f3na" },
            { "sgd", "singapurski dolar" },
            { "shp", "St. Helenski punt" },
            { "sle", "sierra-leoneski leone" },
            { "sll", "sierra-leoneski leone (1964\u20142022)" },
            { "sos", "somaliski \u0161iling" },
            { "srd", "surinamski dolar" },
            { "ssp", "ju\u017enosudanski punt" },
            { "std", "s\u00e3o tomeski dobra (1977\u20132017)" },
            { "stn", "s\u00e3o tomeski dobra" },
            { "svc", "el salvadorski col\u00f3n" },
            { "syp", "syriski punt" },
            { "szl", "swasiski lilangeni" },
            { "thb", "thaiski baht" },
            { "tjs", "tad\u017aikski somoni" },
            { "tmt", "turkmenski manat" },
            { "tnd", "tuneziski dinar" },
            { "top", "tongaski pa\u02bbanga" },
            { "try", "turkowska lira" },
            { "ttd", "trinidad-tobagoski dolar" },
            { "twd", "nowy taiwanski dolar" },
            { "tzs", "tansaniski \u0161iling" },
            { "uah", "ukrainska hriwna" },
            { "ugx", "ugandaski \u0161iling" },
            { "usd", "ameriski dolar" },
            { "uyu", "uruguayski peso" },
            { "uzs", "uzbekski sum" },
            { "vef", "venezuelski bol\u00edvar (2008\u20132018)" },
            { "ves", "venezuelski bol\u00edvar" },
            { "vnd", "vietnamski dong" },
            { "vuv", "vanuatuski vatu" },
            { "wst", "samoaski tala" },
            { "xaf", "CFA-frank (BEAC)" },
            { "xcd", "wuchodnokaribiski dolar" },
            { "xof", "CFA-frank (BCEAO)" },
            { "xpf", "CFP-frank" },
            { "xxx", "njeznata m\u011bna" },
            { "yer", "jemenski rial" },
            { "zar", "ju\u017enoafriski rand" },
            { "zmw", "sambiski kwacha" },
        };
        return data;
    }
}
